package com.jsowell.pile.service;

import java.util.List;

import com.jsowell.pile.domain.ThirdPartySettingInfo;

/**
 * 第三方平台配置Service接口
 *
 * @author jsowell
 * @date 2023-05-24
 */
public interface IThirdPartySettingInfoService {
    /**
     * 查询第三方平台配置
     *
     * @param id 第三方平台配置主键
     * @return 第三方平台配置
     */
    public ThirdPartySettingInfo selectThirdPartySettingInfoById(Long id);

    /**
     * 查询第三方平台配置列表
     *
     * @param thirdPartySettingInfo 第三方平台配置
     * @return 第三方平台配置集合
     */
    public List<ThirdPartySettingInfo> selectThirdPartySettingInfoList(ThirdPartySettingInfo thirdPartySettingInfo);


    /**
     * 查询第三方平台配置信息
     * @param thirdPartySettingInfo
     * @return
     */
    ThirdPartySettingInfo selectSettingInfo(ThirdPartySettingInfo thirdPartySettingInfo);

    /**
     * 新增第三方平台配置
     *
     * @param thirdPartySettingInfo 第三方平台配置
     * @return 结果
     */
    public int insertThirdPartySettingInfo(ThirdPartySettingInfo thirdPartySettingInfo);

    /**
     * 修改第三方平台配置
     *
     * @param thirdPartySettingInfo 第三方平台配置
     * @return 结果
     */
    public int updateThirdPartySettingInfo(ThirdPartySettingInfo thirdPartySettingInfo);

    /**
     * 批量删除第三方平台配置
     *
     * @param ids 需要删除的第三方平台配置主键集合
     * @return 结果
     */
    public int deleteThirdPartySettingInfoByIds(Long[] ids);

    /**
     * 删除第三方平台配置信息
     *
     * @param id 第三方平台配置主键
     * @return 结果
     */
    public int deleteThirdPartySettingInfoById(Long id);

    /**
     * 根据站点id 查询配置列表
     *
     * @param stationId
     * @return
     */
    public ThirdPartySettingInfo getInfoByStationId(Long stationId);

    /**
     * 修改站点互联互通配置
     * @param info
     * @return
     */
    int updateStationSettingInfo(ThirdPartySettingInfo info);
}
