package com.jsowell.web.controller.pile;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jsowell.common.annotation.Log;
import com.jsowell.common.core.controller.BaseController;
import com.jsowell.common.core.domain.AjaxResult;
import com.jsowell.common.enums.BusinessType;
import com.jsowell.pile.domain.ThirdPartySettingInfo;
import com.jsowell.pile.service.IThirdPartySettingInfoService;
import com.jsowell.common.util.poi.ExcelUtil;
import com.jsowell.common.core.page.TableDataInfo;

/**
 * 第三方平台配置Controller
 * 
 * @author jsowell
 * @date 2023-05-24
 */
@RestController
@RequestMapping("/pile/info")
public class ThirdPartySettingInfoController extends BaseController
{
    @Autowired
    private IThirdPartySettingInfoService thirdPartySettingInfoService;

    /**
     * 查询第三方平台配置列表
     */
    @PreAuthorize("@ss.hasPermi('pile:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(ThirdPartySettingInfo thirdPartySettingInfo)
    {
        startPage();
        List<ThirdPartySettingInfo> list = thirdPartySettingInfoService.selectThirdPartySettingInfoList(thirdPartySettingInfo);
        return getDataTable(list);
    }

    /**
     * 导出第三方平台配置列表
     */
    @PreAuthorize("@ss.hasPermi('pile:info:export')")
    @Log(title = "第三方平台配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ThirdPartySettingInfo thirdPartySettingInfo)
    {
        List<ThirdPartySettingInfo> list = thirdPartySettingInfoService.selectThirdPartySettingInfoList(thirdPartySettingInfo);
        ExcelUtil<ThirdPartySettingInfo> util = new ExcelUtil<ThirdPartySettingInfo>(ThirdPartySettingInfo.class);
        util.exportExcel(response, list, "第三方平台配置数据");
    }

    /**
     * 获取第三方平台配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('pile:info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(thirdPartySettingInfoService.selectThirdPartySettingInfoById(id));
    }

    /**
     * 新增第三方平台配置
     */
    @PreAuthorize("@ss.hasPermi('pile:info:add')")
    @Log(title = "第三方平台配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ThirdPartySettingInfo thirdPartySettingInfo)
    {
        return toAjax(thirdPartySettingInfoService.insertThirdPartySettingInfo(thirdPartySettingInfo));
    }

    /**
     * 修改第三方平台配置
     */
    @PreAuthorize("@ss.hasPermi('pile:info:edit')")
    @Log(title = "第三方平台配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ThirdPartySettingInfo thirdPartySettingInfo)
    {
        return toAjax(thirdPartySettingInfoService.updateThirdPartySettingInfo(thirdPartySettingInfo));
    }

    /**
     * 删除第三方平台配置
     */
    @PreAuthorize("@ss.hasPermi('pile:info:remove')")
    @Log(title = "第三方平台配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(thirdPartySettingInfoService.deleteThirdPartySettingInfoByIds(ids));
    }
}
